@@ -3,12 +3,16 @@ import aiohttp
 from bs4 import BeautifulSoup
 import logging
 
-logger = logging.getLogger()
+class AsyncRequestException(Exception):
+    pass
+
 
 
 async def async_get(url, session):
     try:
         async with session.get(url=url) as response:
+            if response.status != 200:
+                raise AsyncRequestException(f"status is {response.status}, {url}")
             resp = await response.read()
             logging.info("Successfully got url {} with resp of length {}.".format(url, len(resp)))
             soup = BeautifulSoup(resp, features="html.parser")
@@ -27,4 +31,5 @@ async def async_gets(url_list):
 class AsyncCWRequest:
     @classmethod
     def execute(self, url_list):
-        return asyncio.run(async_gets(url_list))
\ No newline at end of file
+        result = asyncio.run(async_gets(url_list))
+        return result
\ No newline at end of file
